#!/bin/sh
#
# Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
#
# Contact: Marcell Lengyel <marcell.lengyel@nokia.com>
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public License
# version 2.1 as published by the Free Software Foundation.
#
# This library is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
# 02110-1301 USA
#

set -eu
#exec 2>> /tmp/developer-mode-sh.log; date >&2; pwd >&2; set -x; : ::: "$@"

die () { echo "$@" >&2; exit 1; }

desktop_dir='/usr/share/applications'
__desktop_file_rename ()
{
	mv -f $desktop_dir/$1.$2 $desktop_dir/$1.$3 || :
}
_desktop_files_enable ()
{
	for f; do __desktop_file_rename $f disabled desktop; done
}
_desktop_files_disable ()
{
	for f; do __desktop_file_rename $f desktop disabled; done
}

master_pkgs='sdk-connectivity-tool meego-terminal'
enable_master ()
{
	test -f /etc/developer-mode.conf ||
	mv -f /etc/developer-mode.disabled /etc/developer-mode.conf || :
	touch /etc/developer-mode.conf # XXX remove mad-developer dependency...
	_desktop_files_enable $master_pkgs
	/usr/lib/mad-developer/mode.sh enable || :
	/sbin/initctl start ssh || : # XXX temporary
}
disable_master ()
{
	/usr/lib/mad-developer/mode.sh disable || :
	_desktop_files_disable $master_pkgs
	mv -f /etc/developer-mode.conf /etc/developer-mode.disabled || :
}

sshd=/usr/sbin/sshd

enable_ssh ()
{
	test -f $sshd || mv -f $sshd.disabled $sshd || :
	/sbin/initctl start ssh || :
}

disable_ssh ()
{
	/sbin/initctl stop ssh || :
	test -f $sshd && mv -f $sshd $sshd.disabled || :
	pkill -9 sshd || :
}

enable_vnc () { :; }
disable_vnc () { :; }

enable_energy_profiler () { _desktop_files_enable energy-profiler; }
disable_energy_profiler () { _desktop_files_disable energy-profiler; }

enable_tctswitch () { _desktop_files_enable tctswitch; }
disable_tctswitch () { _desktop_files_disable tctswitch; }


# In the xpkgs package list, all '-':s are replaced with '_'.
xpkgs='ssh vnc energy_profiler tctswitch'

enable ()
{
	case $1 in '')	enable_master ;; esac

	for p in $xpkgs
	do case $1 in ''|$p) enable_$p ;; esac
	done
}

disable ()
{
	case $1 in '')	disable_master ;; esac

	for p in $xpkgs
	do case $1 in ''|$p) disable_$p ;; esac
	done
}

case ${1:-} in
	enable) enable "${2:-}" ;;
	disable) disable "${2:-}" ;;
	*) die Usage: $0 '(enable|disable)' '[pkg]' ;;
esac
exit

Local variables:
mode: shell-script
sh-basic-offset: 8
tab-width: 8
End:
vi: set sw=8 ts=8
